package com.isu.gaswellwatch.controller;

import com.isu.gaswellwatch.annotation.OperationLog;
import com.isu.gaswellwatch.dto.MenuDTO;
import com.isu.gaswellwatch.dto.MenuEditDTO;
import com.isu.gaswellwatch.dto.MenuSortDTO;
import com.isu.gaswellwatch.entity.Response;
import com.isu.gaswellwatch.enums.LogType;
import com.isu.gaswellwatch.service.MenuService;
import com.isu.gaswellwatch.vo.MenuListVO;
import com.isu.gaswellwatch.vo.MenuTreeVO;
import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import org.springframework.web.bind.annotation.*;

import java.util.List;


@RestController
@RequestMapping("menu")
public class MenuController {
    /**
     * 服务对象
     */
    @Resource
    private MenuService menuService;

    /**
     * 根据角色id查菜单树
     * @param roleId  角色id
     * @return 返回菜单树
     */
    @GetMapping("/getMenuTreeByRoleId")
    public Response<List<MenuTreeVO>> getMenuTreeByRoleId(@RequestParam Long roleId){
        return Response.succeed(menuService.getMenuTreeByRoleId(roleId));
    }

    /**
     * 根据角色id查菜单列表
     * @param roleId  角色id
     * @return 返回菜单列表
     */
    @GetMapping("/getMenuListByRoleId")
    public Response<List<MenuListVO>> getMenuListByRoleId(@RequestParam Long roleId){
        return Response.succeed(menuService.getMenuListByRoleId(roleId));
    }

    /**
     * 获取所有菜单树
     * @return 菜单树
     */

    @GetMapping("/getMenuTree")
    public Response<List<MenuTreeVO>> getMenuTree(){
        return Response.succeed(menuService.getMenuTree());
    }

    /**
     * 新增
     * @param menuDTO
     * @return
     */

    @PostMapping("/add")
    @OperationLog(description = "新增菜单",type = LogType.ADD)
    public Response<String> add(@RequestBody @Valid MenuDTO menuDTO){
        menuService.add(menuDTO);
        return Response.succeed();
    }

    /**
     * 编辑
     * @param menuEditDTO
     * @return
     */

    @PostMapping("/edit")
    @OperationLog(description = "修改菜单",type = LogType.UPDATE)
    public Response<String> edit(@RequestBody @Valid MenuEditDTO menuEditDTO){
        menuService.edit(menuEditDTO);
        return Response.succeed();
    }

    /**
     * 删除
     * @param ids
     * @return
     */

    @PostMapping("delete")
    @OperationLog(description = "删除菜单",type = LogType.DELETE)
    public Response<String> delete(@RequestBody List<Long> ids){
        menuService.delete(ids);
        return Response.succeed();
    }

    /**
     * 修改菜单排序
     * @param menuSortDTOList
     * @return 无
     */

    @PostMapping("/editSort")
    @OperationLog(description = "修改菜单排序",type = LogType.UPDATE)
    public Response<String> editSort(@RequestBody @Valid List<MenuSortDTO> menuSortDTOList){
        menuService.editSort(menuSortDTOList);
        return Response.succeed();
    }
    
}

